@@ -40,10 +40,10 @@ Git::Gitalist::HasUtils - Role for classes with an instance of Git::Gitalist::Ut
 
 =head1 AUTHORS
 
-See L<Gitalist> for authors.
+See L<Git::Gitalist> for authors.
 
 =head1 LICENSE
 
-See L<Gitalist> for the license.
+See L<Git::Gitalist> for the license.
 
 =cut
